@@ -156,6 +156,7 @@ OperatorPropertiesKeysType = Literal[
     "CONCAT_FORMAT",
     "DATA_TYPE",
     "DESTINATION_DATA_TYPE",
+    "EXCLUDE_SOURCE_FIELDS_LIST",
     "LOWER_BOUND",
     "MASK_LENGTH",
     "MASK_VALUE",
@@ -299,7 +300,9 @@ SlackConnectorOperatorType = Literal[
     "VALIDATE_NON_ZERO",
     "VALIDATE_NUMERIC",
 ]
-TaskTypeType = Literal["Arithmetic", "Filter", "Map", "Mask", "Merge", "Truncate", "Validate"]
+TaskTypeType = Literal[
+    "Arithmetic", "Filter", "Map", "Map_all", "Mask", "Merge", "Truncate", "Validate"
+]
 TrendmicroConnectorOperatorType = Literal[
     "ADDITION",
     "DIVISION",
